Learn R Programming

aRpsDCA (version 1.0.0)

arps.eur: EUR and time-to-limit for Arps decline curves

Description

Evaluate estimated ultimate recovery and time to economic limit for Arps decline curve objects.

Usage

arps.eur(decl, q.limit)
arps.t.el(decl, q.limit)

Arguments

decl
an Arps decline object as returned by arps.decline or curtail.
q.limit
economic limit rate [volume / time] in same units as decl.

Value

  • arps.eur returns the total production for decl at the point in time when the economic limit q.limit is reached; that is, arps.Np(decl, arps.t.el(decl, q.limit)), in the same units as q.limit.

    arps.t.el returns the time until the economic limit q.limit is reached for decline decl.

See Also

arps, curtail.

Examples

Run this code
## exponential decline with
## qi = 1000 Mscf/d, Di = 95% effective / year
## EUR with economic limit 10 Mscf/d
decline <- arps.decline(1000,
    as.nominal(0.95, from.period="year", to.period="day"))
arps.eur(decline, 10)

## hyperbolic decline with
## qi = 500 bopd, Di = 3.91 nominal / year, b = 1.5,
## time to reach economic limit of 3 bopd
decline <- arps.decline(rescale.by.time(500, from="day", to="year"),
    3.91, 1.5)
arps.t.el(decline, rescale.by.time(3, from="day", to="year"))

Run the code above in your browser using DataLab